#!/usr/bin/python
#-*-coding:utf-8-*-
"""
    Synchronise l'annuaire ldap avec la base de données posh
"""
import getopt, sys
from posh.api.scribe_api import ScribePosh
DOC = """
Usage : synchronize.py [OPTION]
Synchronise les classes de l'annuaire ldap dans Posh

Optionnels:
-t,  --type   : type de groupe à synchroniser (Classe, Equipe, Service...)
-n,  --name   : nom du groupe à synchroniser
-f,  --force  : forcer la synchronisation du groupe (dans le cas où un groupe a déjà été créé il n'est pas resynchronisé sans cette option)

Ex :
1) synchronize.py
ajoute toutes les classes et utilisateurs de l'annuaire dans la base portail

2) synchronize.py -t Niveau
ajoute les niveau et leurs utilisateurs

3) synchronize.py -n 3eme1
ajoute le groupe 3eme1 et ses utilisateurs
"""

def usage():
    """
        print la doc
    """
    print DOC

def main():
    """
        lance la commande
    """
    try:
        opts, args = getopt.getopt(sys.argv[1:], "n:t:fh",
 ["name", "type", "force", "help"])
    except getopt.GetoptError, err:
        print str(err)
        usage()
        sys.exit(2)
    grouptype = None
    groupname = None
    force = False
    for option, value in opts:
        if option in ("-h", "--help"):
            usage()
            sys.exit(0)
        elif option in ("-t", "--type"):
            grouptype = value
        elif option in ("-n", "--name"):
            groupname = value
        elif option in ("-f", "--name"):
            force = True
        else:
            usage()
            assert False, "unhandled option"
    scribe_api = ScribePosh()
    if groupname:
        scribe_api.synchronize_usergroup(groupname, force=force)
        scribe_api.synchronize_group(groupname, force=force)
    elif grouptype:
        scribe_api.synchronize_usergroups(grouptype, force=force)
        scribe_api.synchronize_groups(grouptype, force=force)
    else:
        scribe_api.synchronize_usergroups(_type='Classe', force=force)
        scribe_api.synchronize_groups(_type='Classe', force=force)
        scribe_api.synchronize_usergroups(_type='Equipe', force=force)
        scribe_api.synchronize_groups(_type='Equipe', force=force)
        scribe_api.synchronize_usergroups(_type='Matiere', force=force)
        scribe_api.synchronize_groups(_type='Matiere', force=force)
    sys.exit(0)

if __name__ == "__main__":
    main()
